@@ -1,25 +1,59 @@
 #!/usr/bin/env python
 
 from __future__ import print_function
+from __future__ import absolute_import
 
 # pyslice.py
-#    Copyright (C) 2001  Tim Cera timcera@earthlink.net
-#    http://home.earthlink.net/~timcera
+#    Copyright (C) 2001  Tim Cera tim@cerazone.net
 #
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
+#     * Redistributions of source code must retain the above copyright
+#       notice, this list of conditions and the following disclaimer.
+#     * Redistributions in binary form must reproduce the above copyright
+#       notice, this list of conditions and the following disclaimer in the
+#       documentation and/or other materials provided with the distribution.
+#     * Neither the name pyslice nor the
+#       names of its contributors may be used to endorse or promote products
+#       derived from this software without specific prior written permission.
 #
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
+# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+# ===imports======================
+import sys
+import os
+import os.path
+import getopt
+import time
+import subprocess
+import re
+import shlex
+import shutil
+import filecmp
+import math
+
+# To support montecarlo...
+import random
+
+from binaryornot.check import is_binary
+
+try:
+    import threading as _threading
+except ImportError:
+    import dummy_threading as _threading
+
+import configparser as configparser
+
+from pyslice.pyslice_lib import PySPG as pyspg
 
 """
 NAME:
@@ -47,57 +81,20 @@ EXAMPLES:
         ...
 """
 
-#===imports======================
-import sys
-import os
-import getopt
-import time
-import subprocess
-import os.path
-import re
-import shlex
-try:
-    import configparser
-except ImportError:
-    import ConfigParser as configparser
-import shutil
-import filecmp
-import math
-# To support montecarlo...
-import random
 
-try:
-    import threading as _threading
-except ImportError:
-    import dummy_threading as _threading
-
-try:
-    import pyslice_lib.PySPG as pyspg
-except ImportError:
-    from .pyslice_lib import PySPG as pyspg
-
-# 2/3 compatibility
-try:
-    input = raw_input
-except NameError:
-    pass
-
-#===globals======================
+# ===globals======================
 modname = "pyslice"
 __version__ = "1.6.5"
-LINEENDS = '\r\n'
+LINEENDS = "\r\n"
 
 
-#--option args--
+# --option args--
 debug_p = 0
 
 global input_file
 input_file = "pyslice.ini"
 
-#---positional args, default is empty---
-pargs = []
-
-#---other---
+# ---other---
 
 # Didn't want to have an infinite amount of jobs.
 # This is just for if user makes max_threads <= 0.
@@ -105,7 +102,7 @@ total_processes = 64
 numargs = 2
 speciallines = {}
 
-#===utilities====================
+# ===utilities====================
 
 
 def msg(txt):
@@ -115,13 +112,13 @@ def msg(txt):
 
 def debug(ftn, txt):
     if debug_p:
-        tmp = "".join([modname, '.', ftn, ':', txt, '\n'])
+        tmp = "".join([modname, ".", ftn, ":", txt, "\n"])
         sys.stdout.write(tmp)
         sys.stdout.flush()
 
 
 def fatal(ftn, txt):
-    tmp = "".join([modname, '.', ftn, ':FATAL:', txt, '\n'])
+    tmp = "".join([modname, ".", ftn, ":FATAL:", txt, "\n"])
     raise SystemExit(tmp)
 
 
@@ -129,43 +126,13 @@ def usage():
     print(__doc__)
 
 
-def mask(charlist):
-    """
-    Construct a mask suitable for s.translate,
-    which marks letters in charlist as "t" and ones not as "b".
-    Used by 'istext' function to identify text files.
-    """
-    maskvar = ""
-    for i in range(256):
-        if chr(i) in charlist:
-            maskvar = maskvar + "t"
-        else:
-            maskvar = maskvar + "b"
-    return maskvar
-
-ascii7bit = "".join(
-    list(map(chr, list(range(32, 127))))) + "\r\n\t\b"
-ascii7bit_mask = mask(ascii7bit)
-
-
-def istext(filename, check=1024, mask=ascii7bit_mask):
-    """
-    Returns true if the first check characters in file
-    are within mask, false otherwise.
-    """
-    with open(filename, 'r') as filep:
-        s = filep.read(check)
-    s = s.translate(mask)
-    if s.find("b") != -1:
-        return 0
-    return 1
-
 def assignment(var1, var2):
     try:
         return var1
     except:
         return var2
 
+
 # User-defined Exceptions
 
 
@@ -188,18 +155,19 @@ class NotValidTypeError(Exception):
 class TemplatePathNotFoundError(Exception):
     pass
 
-#====================================
+
+# ====================================
 
 
-class Pyslice:
-    #---class variables---
-    #--------------------------
+class Pyslice(object):
+    # ---class variables---
+    # --------------------------
 
     def __init__(self):
-        #---instance variables---
+        # ---instance variables---
         pass
 
-    #--------------------------
+    # --------------------------
     def read_config(self, min_sections, max_sections, req_sections_list):
         """ Reads the pyslice.ini file.
 
@@ -209,7 +177,8 @@ class Pyslice:
         pyslice_ini = os.path.join(os.getcwd(), input_file)
         if not os.access(pyslice_ini, os.F_OK | os.R_OK):
             raise ConfigFileNotFoundError(
-                "%s was not found or not readable ***" % (input_file,))
+                "%s was not found or not readable ***" % (input_file,)
+            )
         # Read it in.
         config_dict = configparser.ConfigParser()
         config_dict.read(pyslice_ini)
@@ -218,12 +187,14 @@ class Pyslice:
         num_sections = len(config_dict.sections())
         if num_sections < min_sections or num_sections > max_sections:
             raise NumberConfigSectionsError(
-                "pyslice.ini must have between %d and %d sections." %
-                (min_sections, max_sections))
+                "pyslice.ini must have between %d and %d sections."
+                % (min_sections, max_sections)
+            )
         for sec in req_sections_list:
             if not config_dict.has_section(sec):
                 raise RequiredSectionNotFoundError(
-                    "pyslice.ini requires the [%s] section." % sec)
+                    "pyslice.ini requires the [%s] section." % sec
+                )
 
         # Return pyslice.ini as dictionary.
         return config_dict
@@ -233,8 +204,8 @@ class Pyslice:
             This corrects a mistake that I would commonly make.
 
         """
-        in_str = in_str.replace('\'', '')
-        in_str = in_str.replace('\"', '')
+        in_str = in_str.replace("'", "")
+        in_str = in_str.replace('"', "")
         return in_str
 
     def path_correction(self, path):
@@ -253,7 +224,7 @@ class Pyslice:
     def create_output(self, var_set, dirname, dirs, fnames):
         var_dict = {}
         for variables in var_set[1:]:
-            exec('%s = %s' % (variables[0], variables[1]))
+            exec("%s = %s" % (variables[0], variables[1]))
             var_dict[variables[0]] = variables[1]
 
         try:
@@ -262,7 +233,7 @@ class Pyslice:
             pass
         for dirn in dirs:
             infilepath = os.path.join(dirname, dirn)
-            rel_dir = infilepath.replace(_template_path + os.sep, '')
+            rel_dir = infilepath.replace(_template_path + os.sep, "")
             try:
                 os.makedirs(os.path.join(_output_path, _strtag, rel_dir))
             except OSError:
@@ -275,31 +246,33 @@ class Pyslice:
             if excludeflag:
                 continue
             infilepath = os.path.join(dirname, files)
-            rel_dir = infilepath.replace(_template_path + os.sep, '')
+            rel_dir = infilepath.replace(_template_path + os.sep, "")
             outfilepath = os.path.join(_output_path, _strtag, rel_dir)
 
             # Is this a text file?  If so, just open as a template
-            if istext(infilepath):
-                with open(infilepath, 'r') as inputf:
-                    with open(outfilepath, 'w') as output:
+            if not is_binary(infilepath):
+                with open(infilepath, "r") as inputf:
+                    with open(outfilepath, "w") as output:
                         shutil.copystat(infilepath, outfilepath)
 
                         filetotalizer = []
-                        # Search for _keywordvarname_keyword and replace with appropriate
-                        # value.
+                        # Search for _keywordvarname_keyword and replace with
+                        # appropriate value.
                         escaped_keyword = re.escape(_keyword)
                         keyword_search = re.compile(escaped_keyword)
                         search_for = re.compile(
-                            escaped_keyword + '(.*?)' + escaped_keyword)
+                            escaped_keyword + "(.*?)" + escaped_keyword
+                        )
 
                         for lineraw in inputf:
                             line = lineraw
                             # Active comments first...
-                            if CODE == line[:len(CODE)]:
+                            if CODE == line[: len(CODE)]:
                                 filetotalizer.append(line)
-                                words = line.split('|')
-                                # There is the possibility that a datafile would WANT to use |
-                                # So fix words up to have 1 or two items...
+                                words = line.split("|")
+                                # There is the possibility that a datafile
+                                # would WANT to use | So fix words up to have
+                                # 1 or two items...
 
                                 # if block length is missing... too cold
                                 if len(words) == 1:
@@ -309,7 +282,7 @@ class Pyslice:
                                 # if template includes | ... too hot
                                 # right now MUST include block length
                                 if len(words) > numargs:
-                                    linetemplate = words[:-2].join('|')
+                                    linetemplate = words[:-2].join("|")
                                     blocklen = int(words[-1])
 
                                 # ... just right
@@ -317,29 +290,37 @@ class Pyslice:
                                     linetemplate = words[0]
                                     blocklen = int(words[1])
 
-                                linetemplate = linetemplate[len(CODE):]
+                                linetemplate = linetemplate[len(CODE) :]
 
                                 # Process special directives
-                                if '~' == linetemplate[1]:
-                                    # Only want to open file once by checking dictionary
+                                if "~" == linetemplate[1]:
+                                    # Only want to open file once by checking
+                                    # dictionary
                                     lookupno, filename = words[0].split()[1:3]
-                                    lookupno = lookupno.split('~')[1]
+                                    lookupno = lookupno.split("~")[1]
                                     try:
                                         speciallines[filename]
                                     except KeyError:
                                         speciallines.setdefault(filename, {})
-                                        for linespecial in open(filename, 'r'):
-                                            # Handle comments and blank lines
-                                            if '#' == linespecial[0]:
-                                                continue
-                                            recno, sep, stemplate = linespecial.partition(
-                                                '|')
-                                            if not stemplate:
-                                                continue
-                                            stemplate = stemplate.rstrip(LINEENDS)
-                                            speciallines[filename][recno] = stemplate
-                                    line_sub = speciallines[filename][
-                                        lookupno].format(**var_dict)
+                                        with open(filename, "r") as lout:
+                                            for line in lout:
+                                                # Handle comments and blank lines
+                                                if "#" == line[0]:
+                                                    continue
+                                                (
+                                                    recno,
+                                                    sep,
+                                                    stemplate,
+                                                ) = line.partition("|")
+                                                if not stemplate:
+                                                    continue
+                                                stemplate = stemplate.rstrip(LINEENDS)
+                                                speciallines[filename][
+                                                    recno
+                                                ] = stemplate
+                                    line_sub = speciallines[filename][lookupno].format(
+                                        **var_dict
+                                    )
 
                                 else:
                                     line_sub = linetemplate.format(**var_dict)
@@ -348,11 +329,11 @@ class Pyslice:
                                     linein = next(inputf)
                                     nline = []
                                     for index, char in enumerate(line_sub):
-                                        if char == '*':
+                                        if char == "*":
                                             nline.append(linein[index])
                                         else:
                                             nline.append(line_sub[index])
-                                    filetotalizer.append(''.join(nline))
+                                    filetotalizer.append("".join(nline))
                             elif keyword_search.search(line):
                                 matchline = line
                                 for matches in search_for.findall(matchline):
@@ -360,53 +341,63 @@ class Pyslice:
                                         if var_name in matches:
                                             # replace variable name with number
                                             match = matches.replace(
-                                                var_name, str(var_dict[var_name]))
-                                            # evaluate Python statement with eval
+                                                var_name, str(var_dict[var_name])
+                                            )
+                                            # evaluate Python statement with
+                                            # eval
                                             match = eval(match)
-                                            # replace variable with calculated value
+                                            # replace variable with calculated
+                                            # value
                                             matchwhat = re.escape(
-                                                _keyword + matches + _keyword)
+                                                _keyword + matches + _keyword
+                                            )
                                             matchline = re.sub(
-                                                matchwhat, str(match), matchline, count=1)
+                                                matchwhat,
+                                                str(match),
+                                                matchline,
+                                                count=1,
+                                            )
                                 filetotalizer.append(matchline)
                             else:
                                 filetotalizer.append(line)
-                        output.write(''.join(filetotalizer))
+                        output.write("".join(filetotalizer))
             else:
                 try:
-                    equalfiles = filecmp.cmp(infilepath, outfilepath)
+                    if filecmp.cmp(infilepath, outfilepath) is False:
+                        shutil.copy(infilepath, outfilepath)
                 except OSError:
                     shutil.copy(infilepath, outfilepath)
                 continue
 
     # Runs the command *com in a new thread.
     def start_thread_process(self, *com):
-        com = ' '.join(com)
+        com = " ".join(com)
         com = shlex.split(com)
         # PYSLICE can be used in subprocess to do different things if script
         # is run outside of Pyslice.
-        os.environ['PYSLICE'] = '1'
-        if os.name != 'nt':
-            p = subprocess.Popen(com,
-                                 shell=True,
-                                 stdin=subprocess.PIPE,
-                                 stdout=subprocess.PIPE,
-                                 stderr=subprocess.STDOUT,
-                                 close_fds=True)
+        os.environ["PYSLICE"] = "1"
+        if os.name != "nt":
+            p = subprocess.Popen(
+                com,
+                stdin=subprocess.PIPE,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.STDOUT,
+                close_fds=True,
+            )
         else:
             # close_fds is not supported on Windows
-            p = subprocess.Popen(com,
-                                 shell=True,
-                                 stdin=subprocess.PIPE,
-                                 stdout=subprocess.PIPE,
-                                 stderr=subprocess.STDOUT)
+            p = subprocess.Popen(
+                com,
+                stdin=subprocess.PIPE,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.STDOUT,
+            )
 
-        (chstdin, chstdouterr) = (p.stdin, p.stdout)
+        chstdouterr = p.communicate()[0]
 
         if _keep_log is True:
-            with open('pyslice.log', 'w') as fo:
-                fo.write(' '.join(str(i) for i in chstdouterr.readlines()))
-
+            with open("pyslice.log", "w") as fo:
+                fo.write(str(chstdouterr))
 
     def run(self):
         global _strtag
@@ -430,32 +421,27 @@ class Pyslice:
             may not use the same number of output directories from previous
             pyslice runs.
 
-            'Press any key to continue . . .' """
-            try:
-                toss_again = raw_input(toss)
-            except NameError:
-                toss_again = input(toss)
+            'Press "Enter" to continue . . .' """
+            _ = input(toss)
 
         # Read the configuration file and set appropriate variables.
         configuration = self.read_config(4, 100, ["paths", "flags", "program"])
-        _template_path = self.dequote(configuration.get("paths",
-                                                        "template_path"))
+        _template_path = self.dequote(configuration.get("paths", "template_path"))
         _output_path = self.dequote(configuration.get("paths", "output_path"))
         _keyword = self.dequote(configuration.get("flags", "keyword"))
         max_threads = configuration.getint("flags", "max_threads")
         try:
-            COMMENT_CODE = configuration.get('flags', 'comment')
+            COMMENT_CODE = configuration.get("flags", "comment")
         except:
-            COMMENT_CODE = 'qwerty'
+            COMMENT_CODE = "qwerty"
         try:
-            DT_CODE = assignment(
-                configuration.get('flags', 'active_comment'), '')
+            DT_CODE = assignment(configuration.get("flags", "active_comment"), "")
         except:
-            DT_CODE = 'qwerty'
+            DT_CODE = "qwerty"
         CODE = COMMENT_CODE + DT_CODE
         _exclude_list = []
-        if configuration.has_option('flags', 'exclude_copy'):
-            _exclude_list = eval(configuration.get('flags', 'exclude_copy'))
+        if configuration.has_option("flags", "exclude_copy"):
+            _exclude_list = eval(configuration.get("flags", "exclude_copy"))
         if max_threads <= 0:
             max_threads = total_processes
         flat_dirs = configuration.getboolean("flags", "flat_dirs")
@@ -479,7 +465,8 @@ class Pyslice:
 
         if not os.path.exists(_template_path):
             raise TemplatePathNotFoundError(
-                "The template path doesn't exists at '%s'" % (_template_path))
+                "The template path doesn't exists at '%s'" % (_template_path)
+            )
 
         # Put all variable names from configuration file into key_list.
         # Create list (from each variable) of lists (from start, stop, incr).
@@ -493,10 +480,9 @@ class Pyslice:
                 # Cheat by using list type
                 var_list.append(".%s" % (variable,))
                 # Find out distribution
-                distribution = 'random.' + configuration.get(variable,
-                                                             "distribution")
+                distribution = "random." + configuration.get(variable, "distribution")
                 samples = configuration.getint(variable, "samples")
-                for samp in range(samples):
+                for _ in range(samples):
                     var_list.append(eval(distribution))
             # Arithmetic
             elif var_type == "arithmetic":
@@ -511,7 +497,10 @@ class Pyslice:
                     var_list.append(i)
             else:
                 raise NotValidTypeError(
-                    "'%s' is not a valid type - ['arithmetic', 'geometric', 'list', or 'montecarlo']" % (var_type,))
+                    "'%s' is not a valid type - "
+                    "['arithmetic', 'geometric', 'list', "
+                    "or 'montecarlo']" % (var_type,)
+                )
 
             # Arithmetic and Geometric types have the same variables
             if var_type == "arithmetic" or var_type == "geometric":
@@ -528,76 +517,100 @@ class Pyslice:
             var_list = [str(i) for i in var_list]
             list_list.append(var_list)
 
-        list_list = [' '.join(i) for i in list_list]
+        list_list = [" ".join(i) for i in list_list]
 
         # This does the cartesian of all of the parameter values.
         pyspg_obj = pyspg.ParamParser(list_list)
 
-        # set will contain ['directory', [var, var_value], [var1, var1_value],
+        # nset will contain ['directory', [var, var_value], [var1, var1_value],
         # ...]
-        set = []
+        nset = []
         # Loop reorganizes the output from PySPG and retrieves the actual
         # values.
 
-        for iter in pyspg_obj:
+        nmax = {}
+        allints = {}
+        for _ in pyspg_obj:
             tmp = []
             # Had to add the 'limit=None' in order to get directories created
             # for the last variable.  Is this a bug in PySPG?
             tmp.append(pyspg_obj.directory_tree(limit=None))
-            for i in list(pyspg_obj.actual_values.items()):
-                tmp.append(i)
-            set.append(tmp)
+
+            for i_iter in pyspg_obj.variables_list:
+                vname = i_iter.get_varname()
+                nval = pyspg_obj.actual_values[vname]
+                try:
+                    nval = int(nval)
+                except ValueError:
+                    allints[vname] = False
+                    try:
+                        nval = float(nval)
+                    except ValueError:
+                        pass
+                if isinstance(nval, int):
+                    if nmax.setdefault(vname, float("-inf")) < nval:
+                        nmax[vname] = nval
+                tmp.append([vname, nval])
+            nset.append(tmp)
 
         while 1:
             try:
-                if sys.argv[1] == 'y':
+                if sys.argv[1] == "y":
                     break
             except IndexError:
                 pass
 
-            toss = '''Configuration results in %s permutations. Continue? (y/n) > ''' % (len(set),)
-            try:
-                inp = raw_input(toss)
-            except NameError:
-                inp = input(toss)
+            toss = (
+                "Configuration results in %s permutations. " "Continue? (y/n) > "
+            ) % (len(nset),)
+            inp = input(toss)
             if not inp:
                 continue
             inp = inp[0]
-            if inp == 'y' or inp == 'Y':
+            if inp == "y" or inp == "Y":
                 break
-            if inp == 'n' or inp == 'N':
+            if inp == "n" or inp == "N":
                 return
             continue
 
-        for var_index, var_set in enumerate(set):
+        nlen = len(str(len(nset)))
+        for var_index, var_set in enumerate(nset):
             # Create label for output directories
             if flat_dirs:
-                _strtag = str(var_index).zfill(5)
+                _strtag = str(var_index + 1).zfill(nlen)
             else:
-                _strtag = var_set[0]
+                _strtag = os.path.curdir + os.path.sep
+                for ivar in var_set[1:]:
+                    if ivar[0] in allints:
+                        fstr = "{0}-{1}{2}"
+                    else:
+                        fstr = (
+                            "{0}-{1:0"
+                            + str(math.ceil(math.log10(nmax[ivar[0]] + 1)))
+                            + "d}{2}"
+                        )
+                    _strtag = _strtag + fstr.format(ivar[0], ivar[1], os.path.sep)
 
             # Create the files and directories from the template
             # Walks the _template_path directory structure
-            #os.path.walk(_template_path, self.create_output, var_set)
+            # os.path.walk(_template_path, self.create_output, var_set)
             for root, dirs, files in os.walk(_template_path):
                 self.create_output(var_set, root, dirs, files)
 
             # Wait until there are less than max_threads.
             while _threading.activeCount() > max_threads:
-                time.sleep(0.01)
+                time.sleep(0.1)
 
             abs_path = os.path.join(_output_path, _strtag)
 
             os.chdir(abs_path)
 
-            a = _threading.Thread(target=self.start_thread_process,
-                                  args=(program,))
+            a = _threading.Thread(target=self.start_thread_process, args=(program,))
             a.start()
 
 
-#=============================
+# =============================
 class Usage(Exception):
-
     def __init__(self, msg):
         self.msg = msg
 
@@ -606,38 +619,34 @@ def main(argv=None):
     if argv is None:
         argv = sys.argv
 
-    ftn = "main"
-
-    option_dict = {
-        'debug': 0,
-        'file': '',
-    }
+    option_dict = {"debug": 0, "file": ""}
     try:
-        opts, pargs = getopt.getopt(argv[1:], 'hvdf:',
-                                    ['help', 'version', 'debug', 'file='])
+        opts, _ = getopt.getopt(
+            argv[1:], "hvdf:", ["help", "version", "debug", "file="]
+        )
     except getopt.error as msg:
         raise Usage(msg)
 
     for opt in opts:
-        if opt[0] == '-h' or opt[0] == '--help':
+        if opt[0] == "-h" or opt[0] == "--help":
             print(modname + ": version=" + __version__)
             usage()
             sys.exit(0)
-        elif opt[0] == '-v' or opt[0] == '--version':
+        elif opt[0] == "-v" or opt[0] == "--version":
             print(modname + ": version=" + __version__)
             sys.exit(0)
-        elif opt[0] == '-d' or opt[0] == '--debug':
-            option_dict['debug'] = 1
+        elif opt[0] == "-d" or opt[0] == "--debug":
+            option_dict["debug"] = 1
             sys.argv.remove(opt[0])
-        elif opt[0] == '-f' or opt[0] == '--file':
-            option_dict['file'] = opt[1]
-            input_file = opt[1]
+        elif opt[0] == "-f" or opt[0] == "--file":
+            option_dict["file"] = opt[1]
             argv.remove(opt[0])
             argv.remove(opt[1])
 
-    #---make the object and run it---
+    # ---make the object and run it---
     main_x = Pyslice()
     main_x.run()
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     sys.exit(main())
